package com.ruoyi.bst.customerFollow.domain;

import java.time.LocalDateTime;

import javax.validation.constraints.Future;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Past;
import javax.validation.constraints.Size;

import org.springframework.format.annotation.DateTimeFormat;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.constant.DictType;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.system.valid.DictValid;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 客户跟进记录对象 bst_customer_follow
 *
 * @author ruoyi
 * @date 2025-01-22
 */
@Data
public class CustomerFollow extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    private Long followId;

    @Excel(name = "客户ID")
    @ApiModelProperty("客户ID")
    private Long customerId;

    @Excel(name = "跟进方式", readConverterExp = "1=电话,2=微信,3=见面,4=其他")
    @ApiModelProperty("跟进方式")
    @DictValid(type = DictType.CUSTOMER_FOLLOW_TYPE, message = "非法的跟进方式")
    @NotBlank(message = "跟进方式不能为空", groups = {ValidGroup.Create.class})
    private String type;

    @Excel(name = "跟进内容")
    @ApiModelProperty("跟进内容")
    @Size(max = 1000, message = "跟进内容不能超过1000个字符")
    private String content;

    @Excel(name = "图片")
    @ApiModelProperty("图片")
    private String picture;

    @Excel(name = "跟进人ID")
    @ApiModelProperty("跟进人ID")
    private Long userId;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "下次跟进时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("下次跟进时间")
    @Future(message = "下次跟进时间不能小于当前时间")
    private LocalDateTime nextFollowTime;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "跟进时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("跟进时间")
    @Past(message = "跟进时间不能大于当前时间")
    private LocalDateTime followTime;
    
    @ApiModelProperty("客户状态")
    @NotBlank(message = "客户状态不能为空", groups = {ValidGroup.Create.class}  )
    @DictValid(type = DictType.CUSTOMER_STATUS, message = "非法的客户状态值")
    private String customerStatus;

    @ApiModelProperty("客户意向强度")
    @NotBlank(message = "客户意向强度不能为空", groups = {ValidGroup.Create.class})
    @DictValid(type = DictType.CUSTOMER_INTENT_LEVEL, message = "非法的意向强度值")
    private String customerIntentLevel;
}
