package com.ruoyi.bst.message.service.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.bst.taskMember.domain.TaskMemberVO;
import org.springframework.stereotype.Service;

import com.google.common.base.Objects;
import com.ruoyi.bst.message.domain.Message;
import com.ruoyi.bst.message.domain.enums.MessageBstType;
import com.ruoyi.bst.message.service.MessageConverter;
import com.ruoyi.bst.task.domain.TaskVO;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmitVO;
import com.ruoyi.common.utils.collection.CollectionUtils;

@Service
public class MessageConverterImpl implements MessageConverter {


    @Override
    public List<Message> toPoByTaskCreate(TaskVO vo) {
        if (vo == null || CollectionUtils.isEmptyElement(vo.getMemberList())) {
            return Collections.emptyList();
        }

        List<Message> result = new ArrayList<>();
        String bstType = MessageBstType.TASK.getValue();
        String title = "新任务";
        String content = String.format("%s创建了一个新任务：%s\n截止时间：%s", vo.getCreateName(), vo.getDescription(), vo.getExpireTime());

        for (TaskMemberVO member : vo.getMemberList()) {
            if (member.getUserId() == null) {
                continue;
            }
            Message message = new Message();
            message.setBstType(bstType);
            message.setBstId(vo.getId());
            message.setUserId(member.getUserId());
            message.setTitle(title);
            message.setContent(content);
            result.add(message);
        }

        return result;
    }

    @Override
    public List<Message> toPoByTaskUpdate(TaskVO vo) {
        if (vo == null || CollectionUtils.isEmptyElement(vo.getMemberList())) {
            return Collections.emptyList();
        }

        List<Message> result = new ArrayList<>();
        String bstType = MessageBstType.TASK.getValue();
        String title = "任务更新";
        String content = String.format("新内容：%s", vo.getDescription());

        for (TaskMemberVO member : vo.getMemberList()) {
            if (member.getUserId() == null) {
                continue;
            }
            Message message = new Message();
            message.setBstType(bstType);
            message.setBstId(vo.getId());
            message.setUserId(member.getUserId());
            message.setTitle(title);
            message.setContent(content);
            result.add(message);
        }

        return result;
    }

    @Override
    public List<Message> toPoByTaskSubmit(TaskSubmitVO vo) {
        if (vo == null) {
            return Collections.emptyList();
        }

        List<Message> result = new ArrayList<>();
        String bstType = MessageBstType.TASK.getValue();
        String title = "任务提交";
        String remark = vo.getRemark() == null ? "--" : vo.getRemark();
        String content = String.format("%s提交了任务：%s\n备注：%s", vo.getUserName(), vo.getTaskDescription(), remark);

        // 获取通知人：任务创建人、除了提交人以外的任务负责人
        List<Long> userIds = vo.getTaskMemberList() == null ? new ArrayList<>() : vo.getTaskMemberList().stream().map(TaskMemberVO::getUserId).collect(Collectors.toList());
        userIds.add(vo.getTaskCreateId());
        userIds = userIds.stream().filter(item -> {
            return item != null && !Objects.equal(item, vo.getUserId());
        }).collect(Collectors.toList());

        for (Long userId : userIds) {
            if (userId == null) {
                continue;
            }
            Message message = new Message();
            message.setBstType(bstType);
            message.setBstId(vo.getTaskId());
            message.setUserId(userId);
            message.setTitle(title);
            message.setContent(content);
            result.add(message);
        }

        return result;
    }

    @Override
    public List<Message> toPoByTaskPass(TaskVO vo) {
        if (vo == null) {
            return Collections.emptyList();
        }

        List<Message> result = new ArrayList<>();
        String bstType = MessageBstType.TASK.getValue();
        String title = "任务完成";
        String content = String.format("任务：%s已完成", vo.getDescription());

        Message message = new Message();
        message.setBstType(bstType);
        message.setBstId(vo.getId());
        message.setUserId(vo.getCreateId());
        message.setTitle(title);
        message.setContent(content);
        result.add(message);

        return result;
    }

    @Override
    public List<Message> toPoByTaskCancel(TaskVO vo) {
        if (vo == null) {
            return Collections.emptyList();
        }

        List<Message> result = new ArrayList<>();
        String bstType = MessageBstType.TASK.getValue();
        String title = "任务取消";
        String content = String.format("任务：%s已取消\n取消原因：%s", vo.getDescription(), vo.getCancelRemark());

        for (TaskMemberVO member : vo.getMemberList()) {
            if (member.getUserId() == null) {
                continue;
            }
            Message message = new Message();
            message.setBstType(bstType);
            message.setBstId(vo.getId());
            message.setUserId(member.getUserId());
            message.setTitle(title);
            message.setContent(content);
            result.add(message);
        }

        return result;
    }

}
