package com.ruoyi.bst.project.mapper;

import java.util.List;

import com.ruoyi.common.vo.LongIntegerVO;
import org.apache.ibatis.annotations.Param;

import com.ruoyi.bst.project.domain.Project;
import com.ruoyi.bst.project.domain.ProjectQuery;
import com.ruoyi.bst.project.domain.ProjectVO;
import com.ruoyi.bst.project.domain.vo.ProjectNameVO;
import com.ruoyi.common.vo.IntegerIntegerVO;
import com.ruoyi.common.vo.StringIntegerVO;

/**
 * 项目Mapper接口
 *
 * @author ruoyi
 * @date 2025-01-22
 */
public interface ProjectMapper
{
    /**
     * 查询项目
     *
     * @param id 项目主键
     * @return 项目
     */
    ProjectVO selectProjectById(Long id);

    /**
     * 查询项目列表
     *
     * @param query 项目
     * @return 项目集合
     */
    List<ProjectVO> selectProjectList(@Param("query")ProjectQuery query);

    /**
     * 新增项目
     *
     * @param project 项目
     * @return 结果
     */
    int insertProject(Project project);

    /**
     * 修改项目
     *
     * @param project 项目
     * @return 结果
     */
    public int updateProject(@Param("data") Project project);

    /**
     * 逻辑删除项目
     *
     * @param ids 项目主键集合
     * @return 结果
     */
    public int logicDel(@Param("ids") List<Long> ids);

    /**
     * 查询项目名称列表
     * @param query 查询条件
     * @return 项目名称列表
     */
    List<ProjectNameVO> selectNameList(@Param("query") ProjectQuery query);

    /**
     * 查询项目数量
     * @param query
     * @return
     */
    int selectCount(@Param("query") ProjectQuery query);

    /**
     * 查询项目数量
     * @param query
     * @return
     */
    List<StringIntegerVO> selectCountGroupByStatus(@Param("query") ProjectQuery query);

    /**
     * 根据条件更新项目
     * @param data 项目数据
     * @param query 查询条件
     * @return 结果
     */
    int updateByQuery(@Param("data") Project data, @Param("query") ProjectQuery query);

    /**
     * 按创建月份分组查询数量
     * @param query
     * @return
     */
    List<IntegerIntegerVO> selectCountGroupByCreateMonth(@Param("query") ProjectQuery query);

    /**
     * 按完成月份分组查询数量
     * @param query
     * @return
     */
    List<IntegerIntegerVO> selectCountGroupByCompleteMonth(@Param("query") ProjectQuery query);

    /**
     * 按开始月份分组查询数量
     * @param query
     * @return
     */
    List<IntegerIntegerVO> selectCountGroupByStartMonth(@Param("query") ProjectQuery query);

    /**
     * 按参与人ID分组查询数量
     * @param query
     * @return
     */
    List<LongIntegerVO> selectCountGroupByMemberUserId(@Param("query") ProjectQuery query);
}
