package com.ruoyi.bst.project.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.project.domain.ProjectVO;
import com.ruoyi.bst.project.service.ProjectAssembler;
import com.ruoyi.bst.projectMember.domain.ProjectMemberQuery;
import com.ruoyi.bst.projectMember.domain.ProjectMemberVO;
import com.ruoyi.bst.projectMember.service.ProjectMemberService;
import com.ruoyi.bst.task.domain.TaskQuery;
import com.ruoyi.bst.task.domain.enums.TaskStatus;
import com.ruoyi.bst.task.service.TaskService;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.vo.LongIntegerVO;
import com.ruoyi.system.user.service.UserService;

@Service
public class ProjectAssemblerImpl implements ProjectAssembler {

    @Autowired
    private TaskService taskService;

    @Autowired
    private UserService userService;

    @Autowired
    private ProjectMemberService projectMemberService;

    @Override
    public void assembleTaskCount(List<ProjectVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        Map<Long, Integer> taskCountMap = this.selectTaskCountByProjects(list, null);

        for (ProjectVO project : list) {
            Integer count = taskCountMap.get(project.getId());
            if (count == null) {
                count = 0;
            }
            project.setTaskCount(count);
        }
    }

    @Override
    public void assembleTaskPassCount(List<ProjectVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        Map<Long, Integer> taskCountMap = this.selectTaskCountByProjects(list, TaskStatus.PASS.getStatus());

        for (ProjectVO project : list) {
            Integer count = taskCountMap.get(project.getId());
            if (count == null) {
                count = 0;
            }
            project.setTaskPassCount(count);
        }
    }

    @Override
    public void assembleTaskProcessCount(List<ProjectVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        Map<Long, Integer> taskCountMap = this.selectTaskCountByProjects(list, TaskStatus.PROCESSING.getStatus());

        for (ProjectVO project : list) {
            Integer count = taskCountMap.get(project.getId());
            if (count == null) {
                count = 0;
            }
            project.setTaskProcessCount(count);
        }
    }

    /**
     * 根据项目id查询任务数量
     */
    private Map<Long, Integer> selectTaskCountByProjects(List<ProjectVO> list, String status) {
        TaskQuery query = new TaskQuery();
        query.setScope(true);
        query.setStatus(status);
        query.setProjectIds(CollectionUtils.map(list, ProjectVO::getId));
        return taskService.selectCountGroupByProject(query)
            .stream()
            .filter(vo -> vo.getKey() != null)
            .collect(Collectors.toMap(LongIntegerVO::getKey, LongIntegerVO::getValue));
    }

    @Override
    public void assembleMemberList(List<ProjectVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        
        ProjectMemberQuery query = new ProjectMemberQuery();
        query.setProjectIds(CollectionUtils.map(list, ProjectVO::getId));
        List<ProjectMemberVO> memberList = projectMemberService.selectProjectMemberList(query);
        
        for (ProjectVO project : list) {
            List<ProjectMemberVO> projectMemberList = memberList.stream()
                .filter(item -> item.getProjectId().equals(project.getId()))
                .collect(Collectors.toList());
            if (CollectionUtils.isEmptyElement(projectMemberList)) {
                projectMemberList = new ArrayList<>();
            }
            project.setMemberList(projectMemberList);
        }
    }
}
