package com.ruoyi.bst.task.domain.enums;

import java.util.List;

import com.ruoyi.common.utils.collection.CollectionUtils;

import lombok.AllArgsConstructor;
import lombok.Getter;

@Getter
@AllArgsConstructor
public enum TaskStatus {

    WAIT_RECEIVE("1", "待接收"),
    PROCESSING("2", "进行中"),
    WAIT_CONFIRM("3", "待确认（停用）"),
    PASS("4", "通过"),
    REJECT("5", "驳回（停用）"),
    CANCEL("6", "取消");

    private final String status;
    private final String name;


    /**
     * 获取可以提交的任务状态
     */
    public static List<String> canSubmit() {
        return CollectionUtils.map(TaskStatus::getStatus, PROCESSING);
    }

    /**
     * 获取可以取消的任务状态
     */
    public static List<String> canCancel() {
        return CollectionUtils.map(TaskStatus::getStatus, WAIT_RECEIVE, PROCESSING);
    }

    /**
     * 获取可以通过的任务状态
     */
    public static List<String> canPass() {
        return CollectionUtils.map(TaskStatus::getStatus, PROCESSING);
    }

    /**
     * 获取可以开始的任务状态
     */
    public static List<String> canStart() {
        return CollectionUtils.map(TaskStatus::getStatus, WAIT_RECEIVE, CANCEL, PASS);
    }

    /**
     * 获取未完成任务状态
     */
    public static List<String> unComplete() {
        return CollectionUtils.map(TaskStatus::getStatus, PROCESSING, WAIT_RECEIVE);
    }

    /**
     * 获取已完成任务状态
     */
    public static List<String> complete() {
        return CollectionUtils.map(TaskStatus::getStatus, PASS);
    }

    /**
     * 获取逾期完成任务状态
     */
    public static List<String> overDueComplete() {
        return CollectionUtils.map(TaskStatus::getStatus);
    }
}
