package com.ruoyi.bst.task.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.projectMember.domain.ProjectMemberVO;
import com.ruoyi.bst.projectMember.service.ProjectMemberService;
import com.ruoyi.bst.task.domain.TaskVO;
import com.ruoyi.bst.task.service.TaskAssembler;
import com.ruoyi.bst.taskMember.domain.TaskMemberVO;
import com.ruoyi.bst.taskMember.domain.enums.TaskMemberStatus;
import com.ruoyi.bst.taskMember.service.TaskMemberService;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmitVO;
import com.ruoyi.bst.taskSubmit.service.TaskSubmitService;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.system.user.service.UserService;

@Service
public class TaskAssemblerImpl implements TaskAssembler {

    @Autowired
    private TaskSubmitService taskSubmitService;

    @Autowired
    private UserService userService;

    @Autowired
    private TaskMemberService taskMemberService;

    @Autowired
    private ProjectMemberService projectMemberService;

    @Override
    public void assembleSubmitList(List<TaskVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        // 查询列表
        List<Long> taskIds = CollectionUtils.map(list, TaskVO::getId);
        List<TaskSubmitVO> submitList = taskSubmitService.selectListByTaskIds(taskIds);

        // 组装列表
        for (TaskVO task : list) {
            List<TaskSubmitVO> taskSubmitList = submitList.stream()
                .filter(item -> Objects.equals(item.getTaskId(), task.getId()))
                .collect(Collectors.toList());
            task.setSubmitList(taskSubmitList);
        }
    }

    @Override
    public void assembleMemberList(List<TaskVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        List<TaskMemberVO> memberList = taskMemberService.selectListByTaskIds(CollectionUtils.map(list, TaskVO::getId));

        for (TaskVO task : list) {
            List<TaskMemberVO> taskMemberList = memberList.stream()
                .filter(item -> Objects.equals(item.getTaskId(), task.getId()))
                .collect(Collectors.toList());
            if (taskMemberList == null) {
                taskMemberList = new ArrayList<>();
            }
            task.setMemberList(taskMemberList);

            // 提交数量
            task.setSubmitCount((int) taskMemberList.stream()
                    .filter(item -> TaskMemberStatus.submited().contains(item.getStatus()))
                    .count()
            );

            // 已读数量
            task.setReceivedCount((int) taskMemberList.stream()
                    .filter(item -> TaskMemberStatus.received().contains(item.getStatus()))
                    .count()
            );
        }
    }


    @Override
    public void assembleProjectMemberList(List<TaskVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        List<Long> projectIds = CollectionUtils.map(list, TaskVO::getProjectId);
        List<ProjectMemberVO> projectMemberList = projectMemberService.selectListByProjectIds(projectIds);

        for (TaskVO task : list) {
            List<ProjectMemberVO> taskProjectMemberList = projectMemberList.stream()
                .filter(item -> Objects.equals(item.getProjectId(), task.getProjectId()))
                .collect(Collectors.toList());
            task.setProjectMemberList(taskProjectMemberList);
        }
    }

}
