package com.ruoyi.bst.taskSubmit.service.impl;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.support.TransactionTemplate;

import com.ruoyi.bst.task.domain.enums.TaskStatus;
import com.ruoyi.bst.task.service.TaskService;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmit;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmitQuery;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmitVO;
import com.ruoyi.bst.taskSubmit.domain.dto.TaskSubmitRejectDTO;
import com.ruoyi.bst.taskSubmit.domain.enums.TaskSubmitStatus;
import com.ruoyi.bst.taskSubmit.mapper.TaskSubmitMapper;
import com.ruoyi.bst.taskSubmit.service.TaskSubmitService;
import com.ruoyi.bst.verify.domain.Verify;
import com.ruoyi.bst.verify.service.VerifyConverter;
import com.ruoyi.bst.verify.service.VerifyService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.vo.LongIntegerVO;

/**
 * 任务提交记录Service业务层处理
 *
 * @author ruoyi
 * @date 2025-02-08
 */
@Service
public class TaskSubmitServiceImpl implements TaskSubmitService
{
    @Autowired
    private TaskSubmitMapper taskSubmitMapper;

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private VerifyService verifyService;

    @Autowired
    private VerifyConverter verifyConverter;

    @Autowired
    private TaskService taskService;

    /**
     * 查询任务提交记录
     *
     * @param id 任务提交记录主键
     * @return 任务提交记录
     */
    @Override
    public TaskSubmitVO selectTaskSubmitById(Long id)
    {
        return taskSubmitMapper.selectTaskSubmitById(id);
    }

    /**
     * 查询任务提交记录列表
     *
     * @param taskSubmit 任务提交记录
     * @return 任务提交记录
     */
    @Override
    public List<TaskSubmitVO> selectTaskSubmitList(TaskSubmitQuery taskSubmit)
    {
        return taskSubmitMapper.selectTaskSubmitList(taskSubmit);
    }

    /**
     * 新增任务提交记录
     *
     * @param taskSubmit 任务提交记录
     * @return 结果
     */
    @Override
    public int insertTaskSubmit(TaskSubmit taskSubmit)
    {
        taskSubmit.setCreateTime(DateUtils.getNowDate());
        return taskSubmitMapper.insertTaskSubmit(taskSubmit);
    }

    /**
     * 修改任务提交记录
     *
     * @param taskSubmit 任务提交记录
     * @return 结果
     */
    @Override
    public int updateTaskSubmit(TaskSubmit taskSubmit)
    {
        return taskSubmitMapper.updateTaskSubmit(taskSubmit);
    }

    /**
     * 批量删除任务提交记录
     *
     * @param ids 需要删除的任务提交记录主键
     * @return 结果
     */
    @Override
    public int deleteTaskSubmitByIds(Long[] ids)
    {
        return taskSubmitMapper.deleteTaskSubmitByIds(ids);
    }

    /**
     * 删除任务提交记录信息
     *
     * @param id 任务提交记录主键
     * @return 结果
     */
    @Override
    public int deleteTaskSubmitById(Long id)
    {
        return taskSubmitMapper.deleteTaskSubmitById(id);
    }

    @Override
    public List<TaskSubmitVO> selectListByTaskIds(List<Long> taskIds) {
        if (CollectionUtils.isEmptyElement(taskIds)) {
            return Collections.emptyList();
        }

        TaskSubmitQuery query = new TaskSubmitQuery();
        query.setTaskIds(taskIds);
        return this.selectTaskSubmitList(query);
    }

    @Override
    public int reject(TaskSubmitRejectDTO dto) {
        // 校验
        ServiceUtil.assertion(dto == null, "参数不允许为空");
        ServiceUtil.assertion(dto.getId() == null, "提交ID不允许为空");
        TaskSubmitVO old = this.selectTaskSubmitById(dto.getId());
        ServiceUtil.assertion(old == null, "ID为%s的提交不存在", dto.getId());
        ServiceUtil.assertion(!TaskSubmitStatus.canReject().contains(old.getStatus()), "ID为%s的提交状态不允许驳回", dto.getId());

        Integer result = transactionTemplate.execute(status -> {
            // 创建审核记录
            Verify verify = verifyConverter.toPo(dto);
            int insertVerify = verifyService.insertVerify(verify);

            // 更新提交数据
            TaskSubmit submit = new TaskSubmit();
            submit.setVerifyId(verify.getId());
            submit.setVerifyTime(LocalDateTime.now());
            submit.setStatus(TaskSubmitStatus.REJECT.getCode());
            TaskSubmitQuery query = new TaskSubmitQuery();
            query.setId(dto.getId());
            query.setStatusList(TaskSubmitStatus.canReject());
            int updateTaskSubmit = this.updateByQuery(submit, query);
            ServiceUtil.assertion(updateTaskSubmit != 1, "更新ID为%s的提交数据失败", dto.getId());

            // 若任务状态是已完成，则更新为进行中
            if (TaskStatus.PASS.getStatus().equals(old.getTaskStatus())) {
                taskService.startTask(old.getTaskId());
            }

            return updateTaskSubmit;
        });

        return result == null ? 0 : result;
    }

    private int updateByQuery(TaskSubmit data, TaskSubmitQuery query) {
        return taskSubmitMapper.updateByQuery(data, query);
    }

    @Override
    public List<LongIntegerVO> selectCountGroupByTaskId(TaskSubmitQuery query) {
        return taskSubmitMapper.selectCountGroupByTaskId(query);
    }

}
