package com.ruoyi.dashboard.customer.service;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.customer.domain.CustomerQuery;
import com.ruoyi.bst.customer.service.CustomerService;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.common.vo.StringIntegerVO;
import com.ruoyi.dashboard.index.domain.brief.BriefKeys;
import com.ruoyi.dashboard.index.domain.brief.CustomerBriefVO;

@Service
public class DashboardCustomerService {

    @Autowired
    private CustomerService customerService;


    public CustomerBriefVO selectCustomerBrief(CustomerQuery query, List<String> keyList) {
        CustomerBriefVO vo = new CustomerBriefVO();

        if (keyList != null) {
            // 状态Map
            if (keyList.contains(BriefKeys.CUSTOMER_STATUS)) {
                List<StringIntegerVO> customerMap = this.selectCountGroupByStatus(query);
                vo.setStatus(customerMap);
            }
            // 今日新增客户
            if (keyList.contains(BriefKeys.CUSTOMER_TODAY_CREATE)) {
                vo.setToday(this.selectTodayCustomerCount(query));
            }
            // 今日已跟进客户
            if (keyList.contains(BriefKeys.CUSTOMER_TODAY_FOLLOWED)) {
                vo.setTodayFollowed(this.selectTodayFollowedCustomerCount(query));
            }
            // 今日待跟进客户
            if (keyList.contains(BriefKeys.CUSTOMER_TODAY_WAIT_FOLLOW)) {
                vo.setTodayWaitFollow(this.selectTodayWaitFollowCustomerCount(query));
            }
            // 即将跟进客户
            if (keyList.contains(BriefKeys.CUSTOMER_SOON_FOLLOW)) {
                vo.setSoonFollow(this.selectSoonFollowCustomerCount(query));
            }
        }
        return vo;
    }

    // 查询即将跟进客户数（下次跟进时间在1~2天）
    private int selectSoonFollowCustomerCount(CustomerQuery customerQuery) {
        CustomerQuery query = new CustomerQuery();
        BeanUtils.copyBeanProp(query, customerQuery);
        query.setNextFollowTimeStart(LocalDate.now().plusDays(1).atStartOfDay());
        query.setNextFollowTimeEnd(LocalDateTime.now().plusDays(2));
        return customerService.selectCount(query);
    }

    // 查询今日待跟进客户数
    private int selectTodayWaitFollowCustomerCount(CustomerQuery customerQuery) {
        CustomerQuery query = new CustomerQuery();
        BeanUtils.copyBeanProp(query, customerQuery);
        query.setNextFollowDate(LocalDate.now());
        return customerService.selectCount(query);
    }

    // 查询客户状态数量
    private List<StringIntegerVO> selectCountGroupByStatus(CustomerQuery customerQuery) {
        CustomerQuery query = new CustomerQuery();
        BeanUtils.copyBeanProp(query, customerQuery);
        return customerService.selectCountGroupByStatus(query);
    }

    // 查询今日已跟进客户数
    private int selectTodayFollowedCustomerCount(CustomerQuery customerQuery) {
        CustomerQuery query = new CustomerQuery();
        BeanUtils.copyBeanProp(query, customerQuery);
        query.setLastFollowDate(LocalDate.now());
        return customerService.selectCount(query);
    }

    // 查询今日新增客户数
    private int selectTodayCustomerCount(CustomerQuery customerQuery) {
        CustomerQuery query = new CustomerQuery();
        BeanUtils.copyBeanProp(query, customerQuery);
        query.setCreateDate(LocalDate.now());
        return customerService.selectCount(query);
    }
}
