package com.ruoyi.system.user.service.impl;

import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

import com.ruoyi.common.vo.LongIntegerVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.project.domain.ProjectQuery;
import com.ruoyi.bst.task.domain.TaskQuery;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.vo.IntegerIntegerVO;
import com.ruoyi.dashboard.project.service.DashboardProjectService;
import com.ruoyi.dashboard.task.service.DashboardTaskService;
import com.ruoyi.system.user.domain.SysUserVO;
import com.ruoyi.system.user.service.UserAssembler;

@Service
public class UserAssemblerImpl implements UserAssembler{

    @Autowired
    private DashboardProjectService dashboardProjectService;

    @Autowired
    private DashboardTaskService dashboardTaskService;

    @Override
    public void assembleProjectCount(List<SysUserVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        ProjectQuery query = new ProjectQuery();
        query.setJoinUserIds(list.stream().map(SysUserVO::getUserId).collect(Collectors.toList()));
        List<LongIntegerVO> result = dashboardProjectService.selectCountGroupByMemberUserId(query);

        for (SysUserVO user : list) {
            LongIntegerVO vo = result.stream()
                .filter(item -> Objects.equals(item.getKey(), user.getUserId()))
                .findFirst()
                .orElse(null);
            if (vo != null) {
                user.setProjectCount(vo.getValue());
            } else {
                user.setProjectCount(0);
            }
        }
    }

    @Override
    public void assembleTaskCount(List<SysUserVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        TaskQuery query = new TaskQuery();
        query.setOwnerIds(list.stream().map(SysUserVO::getUserId).collect(Collectors.toList()));
        List<LongIntegerVO> result = dashboardTaskService.selectCountGroupByMemberUserId(query);

        for (SysUserVO user : list) {
            LongIntegerVO vo = result.stream()
                .filter(item -> Objects.equals(item.getKey(), user.getUserId()))
                .findFirst()
                .orElse(null);
            if (vo != null) {
                user.setTaskCount(vo.getValue());
            } else {
                user.setTaskCount(0);
            }
        }
    }
}
