package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.attach.domain.Attach;
import com.ruoyi.bst.attach.domain.AttachQuery;
import com.ruoyi.bst.attach.domain.AttachVO;
import com.ruoyi.bst.attach.service.AttachConverter;
import com.ruoyi.bst.attach.service.AttachService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 资源Controller
 *
 * @author ruoyi
 * @date 2025-02-12
 */
@RestController
@RequestMapping("/bst/attach")
public class AttachController extends BaseController
{
    @Autowired
    private AttachService attachService;

    @Autowired
    private AttachConverter attachConverter;

    /**
     * 查询资源列表
     */
    @PreAuthorize("@ss.hasPermi('bst:attach:list')")
    @GetMapping("/list")
    public TableDataInfo list(AttachQuery query)
    {
        startPage();
        startOrderBy();
        List<AttachVO> list = attachService.selectAttachList(query);
        return getDataTable(list);
    }

    /**
     * 导出资源列表
     */
    @PreAuthorize("@ss.hasPermi('bst:attach:export')")
    @Log(title = "资源", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AttachQuery query)
    {
        List<AttachVO> list = attachService.selectAttachList(query);
        ExcelUtil<AttachVO> util = new ExcelUtil<AttachVO>(AttachVO.class);
        util.exportExcel(response, list, "资源数据");
    }

    /**
     * 获取资源详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:attach:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(attachService.selectAttachById(id));
    }

    /**
     * 新增资源
     */
    @PreAuthorize("@ss.hasPermi('bst:attach:add')")
    @Log(title = "资源", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Attach attach){
        List<Attach> poList = attachConverter.toPoListByCreate(attach);
        return toAjax(attachService.batchInsert(poList));
    }

    /**
     * 修改资源
     */
    @PreAuthorize("@ss.hasPermi('bst:attach:edit')")
    @Log(title = "资源", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Attach attach)
    {
        Attach po = attachConverter.toPoByUpdate(attach);
        return toAjax(attachService.updateAttach(po));
    }

    /**
     * 删除资源
     */
    @PreAuthorize("@ss.hasPermi('bst:attach:remove')")
    @Log(title = "资源", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(attachService.logicDel(ids));
    }
}
