package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.message.domain.MessageQuery;
import com.ruoyi.bst.message.domain.MessageVO;
import com.ruoyi.bst.message.service.MessageService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 消息Controller
 *
 * @author ruoyi
 * @date 2025-02-22
 */
@RestController
@RequestMapping("/bst/message")
public class MessageController extends BaseController
{
    @Autowired
    private MessageService messageService;

    /**
     * 查询消息列表
     */
    @PreAuthorize("@ss.hasPermi('bst:message:list')")
    @GetMapping("/list")
    public TableDataInfo list(MessageQuery query)
    {
        startPage();
        startOrderBy();
        query.setScope(true);
        List<MessageVO> list = messageService.selectMessageList(query);
        return getDataTable(list);
    }

    /**
     * 导出消息列表
     */
    @PreAuthorize("@ss.hasPermi('bst:message:export')")
    @Log(title = "消息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MessageQuery query)
    {
        List<MessageVO> list = messageService.selectMessageList(query);
        ExcelUtil<MessageVO> util = new ExcelUtil<MessageVO>(MessageVO.class);
        util.exportExcel(response, list, "消息数据");
    }

    /**
     * 获取消息详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:message:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(messageService.selectMessageById(id));
    }

    /**
     * 新增消息
     */
    // @PreAuthorize("@ss.hasPermi('bst:message:add')")
    // @Log(title = "消息", businessType = BusinessType.INSERT)
    // @PostMapping
    // public AjaxResult add(@RequestBody Message message)
    // {
    //     return toAjax(messageService.insertMessage(message));
    // }

    // /**
    //  * 修改消息
    //  */
    // @PreAuthorize("@ss.hasPermi('bst:message:edit')")
    // @Log(title = "消息", businessType = BusinessType.UPDATE)
    // @PutMapping
    // public AjaxResult edit(@RequestBody Message message)
    // {
    //     return toAjax(messageService.updateMessage(message));
    // }

    // /**
    //  * 删除消息
    //  */
    // @PreAuthorize("@ss.hasPermi('bst:message:remove')")
    // @Log(title = "消息", businessType = BusinessType.DELETE)
	// @DeleteMapping("/{ids}")
    // public AjaxResult remove(@PathVariable Long[] ids)
    // {
    //     return toAjax(messageService.deleteMessageByIds(ids));
    // }
}
