package com.ruoyi.web.bst;

import java.util.Collections;
import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.project.domain.ProjectQuery;
import com.ruoyi.bst.project.domain.ProjectVO;
import com.ruoyi.bst.project.domain.dto.ProjectMaintenanceDTO;
import com.ruoyi.bst.project.domain.dto.ProjectStartDTO;
import com.ruoyi.bst.project.service.ProjectAssembler;
import com.ruoyi.bst.project.service.ProjectConverter;
import com.ruoyi.bst.project.service.ProjectService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 项目Controller
 *
 * @author ruoyi
 * @date 2025-01-22
 */
@RestController
@RequestMapping("/bst/project")
public class ProjectController extends BaseController
{
    @Autowired
    private ProjectService projectService;

    @Autowired
    private ProjectConverter projectConverter;

    @Autowired
    private ProjectAssembler projectAssembler;

    /**
     * 查询项目列表
     */
    @PreAuthorize("@ss.hasPermi('bst:project:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProjectQuery query)
    {
        startPage();
        PageHelper.orderBy("sort_score desc, create_time desc");
        startOrderBy();
        query.setScope(true);
        List<ProjectVO> list = projectService.selectProjectList(query);
        projectAssembler.assembleTaskCount(list);
        projectAssembler.assembleTaskPassCount(list);
        projectAssembler.assembleTaskProcessCount(list);
        projectAssembler.assembleMemberList(list);
        return getDataTable(list);
    }

    /**
     * 查询所有项目名称
     */
    @PreAuthorize("@ss.hasPermi('bst:project:list')")
    @GetMapping("/listAll")
    public AjaxResult listAll() {
        return success(projectService.selectAllNameList());
    }

    /**
     * 导出项目列表
     */
    @PreAuthorize("@ss.hasPermi('bst:project:export')")
    @Log(title = "项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProjectQuery query)
    {
        List<ProjectVO> list = projectService.selectProjectList(query);
        ExcelUtil<ProjectVO> util = new ExcelUtil<ProjectVO>(ProjectVO.class);
        util.exportExcel(response, list, "项目数据");
    }

    /**
     * 获取项目详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:project:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        ProjectVO project = projectService.selectProjectById(id);
        List<ProjectVO> list = Collections.singletonList(project);
        projectAssembler.assembleMemberList(list);
        return success(project);
    }

    /**
     * 新增项目
     */
    @PreAuthorize("@ss.hasPermi('bst:project:add')")
    @Log(title = "项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) ProjectVO project)
    {
        project = projectConverter.toVoByCreate(project);
        return toAjax(projectService.insertProject(project));
    }

    /**
     * 修改项目
     */
    @PreAuthorize("@ss.hasPermi('bst:project:edit')")
    @Log(title = "项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) ProjectVO project)
    {
        project = projectConverter.toVoByUpdate(project);
        return toAjax(projectService.updateProject(project));
    }

    /**
     * 删除项目
     */
    @PreAuthorize("@ss.hasPermi('bst:project:remove')")
    @Log(title = "项目", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(projectService.logicDel(ids));
    }

    /**
     * 项目开始
     */
    @PreAuthorize("@ss.hasPermi('bst:project:start')")
    @Log(title = "项目", businessType = BusinessType.UPDATE)
    @PutMapping("/start")
    public AjaxResult start(@RequestBody @Validated ProjectStartDTO dto) {
        return toAjax(projectService.start(dto));
    }

    /**
     * 项目开发完成
     */
    @PreAuthorize("@ss.hasPermi('bst:project:complete')")
    @Log(title = "项目", businessType = BusinessType.UPDATE)
    @PutMapping("/complete/{id}")
    public AjaxResult complete(@PathVariable("id") Long id) {
        return toAjax(projectService.complete(id));
    }

    /**
     * 项目验收
     */
    @PreAuthorize("@ss.hasPermi('bst:project:accept')")
    @Log(title = "项目", businessType = BusinessType.UPDATE)
    @PutMapping("/accept/{id}")
    public AjaxResult accept(@PathVariable("id") Long id) {
        return toAjax(projectService.accept(id));
    }

    /**
     * 维护
     */
    @PreAuthorize("@ss.hasPermi('bst:project:maintenance')")
    @Log(title = "项目", businessType = BusinessType.UPDATE)
    @PutMapping("/maintenance")
    public AjaxResult maintenance(@RequestBody @Validated ProjectMaintenanceDTO dto) {
        return toAjax(projectService.maintenance(dto));
    }
}
