package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.projectMember.domain.ProjectMemberQuery;
import com.ruoyi.bst.projectMember.domain.ProjectMemberVO;
import com.ruoyi.bst.projectMember.service.ProjectMemberService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 项目成员Controller
 *
 * @author ruoyi
 * @date 2025-03-06
 */
@RestController
@RequestMapping("/bst/projectMember")
public class ProjectMemberController extends BaseController
{
    @Autowired
    private ProjectMemberService projectMemberService;

    /**
     * 查询项目成员列表
     */
    @PreAuthorize("@ss.hasPermi('bst:projectMember:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProjectMemberQuery query)
    {
        startPage();
        startOrderBy();
        List<ProjectMemberVO> list = projectMemberService.selectProjectMemberList(query);
        return getDataTable(list);
    }

    /**
     * 导出项目成员列表
     */
    @PreAuthorize("@ss.hasPermi('bst:projectMember:export')")
    @Log(title = "项目成员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProjectMemberQuery query)
    {
        List<ProjectMemberVO> list = projectMemberService.selectProjectMemberList(query);
        ExcelUtil<ProjectMemberVO> util = new ExcelUtil<ProjectMemberVO>(ProjectMemberVO.class);
        util.exportExcel(response, list, "项目成员数据");
    }

    /**
     * 获取项目成员详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:projectMember:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(projectMemberService.selectProjectMemberById(id));
    }

    /**
     * 新增项目成员
    //  */
    // @PreAuthorize("@ss.hasPermi('bst:projectMember:add')")
    // @Log(title = "项目成员", businessType = BusinessType.INSERT)
    // @PostMapping
    // public AjaxResult add(@RequestBody ProjectMember projectMember)
    // {
    //     return toAjax(projectMemberService.insertProjectMember(projectMember));
    // }

    // /**
    //  * 修改项目成员
    //  */
    // @PreAuthorize("@ss.hasPermi('bst:projectMember:edit')")
    // @Log(title = "项目成员", businessType = BusinessType.UPDATE)
    // @PutMapping
    // public AjaxResult edit(@RequestBody ProjectMember projectMember)
    // {
    //     return toAjax(projectMemberService.updateProjectMember(projectMember));
    // }

    // /**
    //  * 删除项目成员
    //  */
    // @PreAuthorize("@ss.hasPermi('bst:projectMember:remove')")
    // @Log(title = "项目成员", businessType = BusinessType.DELETE)
	// @DeleteMapping("/{ids}")
    // public AjaxResult remove(@PathVariable Long[] ids)
    // {
    //     return toAjax(projectMemberService.deleteProjectMemberByIds(ids));
    // }
}
